bluemath\_tk.tide package
=========================

Submodules
----------

bluemath\_tk.tide.harmonic module
---------------------------------

.. automodule:: bluemath_tk.tide.harmonic
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.tide.ttide module
------------------------------

.. automodule:: bluemath_tk.tide.ttide
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.tide.utide module
------------------------------

.. automodule:: bluemath_tk.tide.utide
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bluemath_tk.tide
   :members:
   :undoc-members:
   :show-inheritance:
